@@ -31,14 +31,10 @@
 #  This code is licensed under the GNU General Public License v2.
 #  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
 # ---------------------------------------------------------------------------
-#pylint: disable=broad-except,no-name-in-module
-try:
-    from enum import IntEnum
-    __base = IntEnum
-except Exception:
-    __base = object
 
-class Access(__base):
+from ..GXIntEnum import GXIntEnum
+
+class Access(GXIntEnum):
     """
     Access describes access errors.
     """
