@@ -32,6 +32,7 @@
 #  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
 # ---------------------------------------------------------------------------
 import math
+import datetime
 from .GXDLMSObject import GXDLMSObject
 from .IGXDLMSBase import IGXDLMSBase
 from ..enums import ErrorCode
@@ -75,6 +76,28 @@ class GXDLMSDemandRegister(GXDLMSObject, IGXDLMSBase):
                 self.period,
                 self.numberOfPeriods]
 
+    def reset(self, client):
+        """Reset value."""
+        return client.method(self.getName(), self.objectType, 1, 0, DataType.INT8)
+
+    def nextPeriod(self, client):
+        """Closes the current period and starts a new one."""
+        return client.method(self.getName(), self.objectType, 2, 0, DataType.INT8)
+
+    def invoke(self, settings, e):
+        #  Resets the value to the default value.
+        #  The default value is an instance specific constant.
+        if e.index == 1:
+            self.currentAverageValue = None
+            self.lastAverageValue = None
+            self.startTimeCurrent = self.captureTime = datetime.datetime.now()
+        elif e.index == 2:
+            self.lastAverageValue = self.currentAverageValue
+            self.currentAverageValue = None
+            self.startTimeCurrent = self.captureTime = datetime.datetime.now()
+        else:
+            e.error = ErrorCode.READ_WRITE_DENIED
+
     def isRead(self, index):
         if index == 4:
             return self.unit != 0
@@ -215,12 +238,12 @@ class GXDLMSDemandRegister(GXDLMSObject, IGXDLMSBase):
             #  Set default values.
             if e.value is None:
                 self.scaler = 1
-                self.unit = 0
+                self.unit = Unit.NONE
             else:
                 if len(e.value) != 2:
                     raise ValueError("setValue failed. Invalid scaler unit value.")
                 self.scaler = math.pow(10, e.value[0])
-                self.unit = e.value[1]
+                self.unit = Unit(e.value[1])
         elif e.index == 5:
             if e.value is None:
                 self.status = None
@@ -263,7 +286,7 @@ class GXDLMSDemandRegister(GXDLMSObject, IGXDLMSBase):
         self.currentAverageValue = reader.readElementContentAsObject("CurrentAverageValue", None, self, 2)
         self.lastAverageValue = reader.readElementContentAsObject("LastAverageValue", None, self, 3)
         self.scaler = reader.readElementContentAsDouble("Scaler", 1)
-        self.unit = reader.readElementContentAsInt("Unit")
+        self.unit = Unit(reader.readElementContentAsInt("Unit"))
         self.status = reader.readElementContentAsObject("Status", None, self, 5)
         self.captureTime = reader.readElementContentAsDateTime("CaptureTime")
         self.startTimeCurrent = reader.readElementContentAsDateTime("StartTimeCurrent")
